@@ -346,6 +346,80 @@ void Component::paint(ViewPainter *p) {
     }
 }
 
+// paint device icon for left panel list
+void Component::paintIcon(QPixmap *pixmap)
+{
+    pixmap->fill(Qt::transparent);
+    QPainter *painter = new QPainter(pixmap);
+    ViewPainter *p = new ViewPainter(painter);
+    int h = std::abs(x2 - x1) + 10;
+    int w = std::abs(y2 - y1) + 10;
+    int ph = pixmap->size().height();
+    p->Scale = (float) ph / std::max(w,h);
+
+    QFont f = p->Painter->font();   // save current font
+    QFont newFont = f;
+    int c_sc = ph / (2*p->Scale);
+    cx += c_sc + icon_dx*p->Scale;
+    cy += c_sc + icon_dy*p->Scale;
+    if (Model.at(0) != '.' && !isEquation) {    // normal components go here
+        // paint all lines
+        QPen portPen;
+        portPen.setWidth(3);
+        portPen.setColor(Qt::red);
+        p->Painter->setPen(portPen);
+        for (auto pp: Ports) {
+            p->drawEllipse(cx+pp->x-2,cy+pp->y-2,4,4);
+        }
+
+        for (qucs::Line *p1: Lines) {
+            p1->style.setWidth(3);
+            p->Painter->setPen(p1->style);
+            p->drawLine(cx + p1->x1, cy + p1->y1, cx + p1->x2, cy + p1->y2);
+        }
+
+        // paint all arcs
+        for (qucs::Arc *p3: Arcs) {
+            p3->style.setWidth(3);
+            p->Painter->setPen(p3->style);
+            p->drawArc(cx + p3->x, cy + p3->y, p3->w, p3->h, p3->angle, p3->arclen);
+        }
+
+        // paint all rectangles
+        for (qucs::Area *pa: Rects) {
+            pa->Pen.setWidth(3);
+            p->Painter->setPen(pa->Pen);
+            p->Painter->setBrush(pa->Brush);
+            p->drawRect(cx + pa->x, cy + pa->y, pa->w, pa->h);
+        }
+
+        // paint all ellipses
+        for (qucs::Area *pa: Ellips) {
+            p->Painter->setPen(pa->Pen);
+            p->Painter->setBrush(pa->Brush);
+            p->drawEllipse(cx + pa->x, cy + pa->y, pa->w, pa->h);
+        }
+        p->Painter->setBrush(Qt::NoBrush);
+
+        newFont.setWeight(QFont::Light);
+
+        for (Text *pt: Texts) {
+            p->Painter->setWorldTransform(
+                    QTransform(pt->mCos, -pt->mSin, pt->mSin, pt->mCos,
+                               p->DX + float(cx + pt->x) * p->Scale,
+                               p->DY + float(cy + pt->y) * p->Scale));
+            newFont.setPointSizeF(p->Scale * pt->Size);
+            newFont.setOverline(pt->over);
+            newFont.setUnderline(pt->under);
+            p->Painter->setFont(newFont);
+            p->Painter->setPen(pt->Color);
+            w = p->drawTextMapped(pt->s, 0, 0, &h);
+            Q_UNUSED(w)
+            Q_UNUSED(h)
+        }
+    }
+}
+
 // -------------------------------------------------------
 // Paints the component when moved with the mouse.
 void Component::paintScheme(Schematic *p) {
