@@ -495,8 +495,9 @@ void Ngspice::slotSimulate()
     }
 
     if (checker_error) {
-        console->insertPlainText(output);
-        emit finished();
+        if (console != nullptr)
+            console->insertPlainText(output);
+        //emit finished();
         emit errors(QProcess::FailedToStart);
         return;
     }
@@ -527,6 +528,7 @@ void Ngspice::slotSimulate()
     QString ngsp_cmd = cmd_args.at(0);
     cmd_args.removeAt(0);
     SimProcess->start(ngsp_cmd,cmd_args);
+    if (QucsMain)
     emit started();
 }
 
