@@ -823,6 +823,11 @@ int main(int argc, char *argv[])
   QucsSettings.maxUndo = 20;
   QucsSettings.NodeWiring = 0;
 
+  QApplication::setAttribute(Qt::AA_EnableHighDpiScaling,true);
+#if QT_VERSION < 0x060000
+  QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps,true);
+#endif
+
   // initially center the application
   QApplication a(argc, argv);
   //QDesktopWidget *d = a.desktop();
@@ -952,10 +957,6 @@ int main(int argc, char *argv[])
   QucsSettings.sysDefaultFont = QApplication::font();
   a.setFont(QucsSettings.appFont);
 
-  // set codecs
-  //QTextCodec::setCodecForLocale(QTextCodec::codecForName("UTF-8"));
-//  QTextCodec::setCodecForTr(QTextCodec::codecForName("UTF-8"));
-
   QTranslator tor( 0 );
   QString lang = QucsSettings.Language;
   if(lang.isEmpty()) {
