@@ -40,10 +40,12 @@ QMap<QString, QString> Module::vaComponents;
 Module::Module () {
   info = 0;
   category = "#special";
+  icon = nullptr;
 }
 
 // Destructor removes instance of module object from memory.
 Module::~Module () {
+    if (icon != nullptr) delete icon;
 }
 
 // Module registration using a category name and the appropriate
@@ -69,6 +71,9 @@ void Module::registerComponent(QString category, pInfoFunc info) {
     Component *c = (Component *) info(Name, File, true);
     Model = c->Model;
 
+    m->icon = new QPixmap(128,128);
+    c->paintIcon(m->icon);
+
     // put into category and the component hash
     if ((c->Simulator & QucsSettings.DefaultSimulator) == QucsSettings.DefaultSimulator) {
         intoCategory(m);
@@ -249,6 +254,9 @@ void Module::registerModules (void) {
   REGISTER_LUMPED_1 (Inductor);
   REGISTER_LUMPED_1 (IndQ);
   REGISTER_LUMPED_1 (CapQ);
+  REGISTER_LUMPED_1 (Mutual);
+  REGISTER_LUMPED_1 (Mutual2);
+  REGISTER_LUMPED_1 (MutualX);
   // lumped components
   //if (QucsSettings.DefaultSimulator != spicecompat::simQucsator) {
       REGISTER_LUMPED_1 (R_SPICE);
@@ -256,12 +264,12 @@ void Module::registerModules (void) {
       REGISTER_LUMPED_1 (L_SPICE);
       REGISTER_LUMPED_1 (K_SPICE);
   //}
-  REGISTER_LUMPED_1 (Ground);
-  REGISTER_LUMPED_1 (SubCirPort);
 
   //if (QucsSettings.DefaultSimulator == spicecompat::simQucsator) {
       REGISTER_LUMPED_1 (Transformer);
       REGISTER_LUMPED_1 (symTrafo);
+      REGISTER_LUMPED_1 (Ground);
+      REGISTER_LUMPED_1 (SubCirPort);
       REGISTER_LUMPED_1 (dcBlock);
       REGISTER_LUMPED_1 (dcFeed);
       REGISTER_LUMPED_1 (BiasT);
@@ -280,9 +288,6 @@ void Module::registerModules (void) {
   REGISTER_LUMPED_1 (vProbe);
 
   //if (QucsSettings.DefaultSimulator == spicecompat::simQucsator) {
-      REGISTER_LUMPED_1 (Mutual);
-      REGISTER_LUMPED_1 (Mutual2);
-      REGISTER_LUMPED_1 (MutualX);
       REGISTER_LUMPED_1 (Switch);
   //} else {
       REGISTER_LUMPED_1 (S4Q_S);
@@ -359,7 +364,9 @@ void Module::registerModules (void) {
       REGISTER_TRANS_1 (TwistedPair);
       REGISTER_TRANS_1 (CoaxialLine);
       REGISTER_TRANS_1 (RectLine);
+      REGISTER_TRANS_1 (CircLine);
       REGISTER_TRANS_1 (RLCG);
+      REGISTER_TRANS_1 (taperedline);
       REGISTER_TRANS_1 (Substrate);
       REGISTER_TRANS_1 (MSline);
       REGISTER_TRANS_1 (MScoupled);
