@@ -36,6 +36,7 @@
 #include "dialogs/labeldialog.h"
 #include "dialogs/textboxdialog.h"
 #include "extsimkernels/customsimdialog.h"
+#include "dialogs/tuner.h"
 
 #include <QTextStream>
 #include <qt3_compat/q3ptrlist.h>
@@ -1241,98 +1242,97 @@ void MouseActions::MPressRotate(Schematic *Doc, QMouseEvent*, float fX, float fY
 
 // -----------------------------------------------------------
 // insert component, diagram, painting into schematic ?!
-void MouseActions::MPressElement(Schematic *Doc, QMouseEvent *Event, float, float)
-{
-  if(selElem == 0) return;
-  //QPainter painter(Doc->viewport());
-  //setPainter(Doc, &painter);
+void MouseActions::MPressElement(Schematic *Doc, QMouseEvent *Event, float, float) {
+    if (selElem == 0) return;
+    //QPainter painter(Doc->viewport());
+    //setPainter(Doc, &painter);
 
 
-  int x1, y1, x2, y2, rot;
-  if(selElem->Type & isComponent) {
-    Component *Comp = (Component*)selElem;
+    int x1, y1, x2, y2, rot;
+    if (selElem->Type & isComponent) {
+        Component *Comp = (Component *) selElem;
 //    qDebug() << "+-+ got to switch:" << Comp->Name;
-    QString entryName = Comp->Name;
+        QString entryName = Comp->Name;
 
-    switch(Event->button()) {
-      case Qt::LeftButton :
-	// left mouse button inserts component into the schematic
-	// give the component a pointer to the schematic it's a
-	// part of
-	Comp->setSchematic (Doc);
-	Comp->textSize(x1, y1);
-	Doc->insertComponent(Comp);
-	Comp->textSize(x2, y2);
-	if(Comp->tx < Comp->x1) Comp->tx -= x2 - x1;
+        switch (Event->button()) {
+            case Qt::LeftButton :
+                // left mouse button inserts component into the schematic
+                // give the component a pointer to the schematic it's a
+                // part of
+                Comp->setSchematic(Doc);
+                Comp->textSize(x1, y1);
+                Doc->insertComponent(Comp);
+                Comp->textSize(x2, y2);
+                if (Comp->tx < Comp->x1) Comp->tx -= x2 - x1;
 
-    // Note: insertCopmponents does increment  name1 -> name2
+                // Note: insertCopmponents does increment  name1 -> name2
 //    qDebug() << "  +-+ got to insert:" << Comp->Name;
 
-	// enlarge viewarea if component lies outside the view
-	Comp->entireBounds(x1,y1,x2,y2, Doc->textCorr());
-	Doc->enlargeView(x1, y1, x2, y2);
+                // enlarge viewarea if component lies outside the view
+                Comp->entireBounds(x1, y1, x2, y2, Doc->textCorr());
+                Doc->enlargeView(x1, y1, x2, y2);
 
-	drawn = false;
-	Doc->viewport()->update();
-	Doc->setChanged(true, true);
-	rot = Comp->rotated;
+                drawn = false;
+                Doc->viewport()->update();
+                Doc->setChanged(true, true);
+                rot = Comp->rotated;
 
-    // handle static and dynamic components
+                // handle static and dynamic components
 //    QucsApp::CompChoose;
-    if (Module::vaComponents.contains(entryName)){
-      QString filename = Module::vaComponents[entryName];
+                if (Module::vaComponents.contains(entryName)) {
+                    QString filename = Module::vaComponents[entryName];
 //      qDebug() << "   ===+ recast";
-      Comp = dynamic_cast<vacomponent*>(Comp)->newOne(filename); //va component
-      qDebug() << "   => recast = Comp;" << Comp->Name << "filename: " << filename;
-    }
-    else {
-	  Comp = Comp->newOne(); // static component is used, so create a new one
-    }
-	rot -= Comp->rotated;
-	rot &= 3;
-	while(rot--) Comp->rotate(); // keep last rotation for single component
-	break;
+                    Comp = dynamic_cast<vacomponent *>(Comp)->newOne(filename); //va component
+                    qDebug() << "   => recast = Comp;" << Comp->Name << "filename: " << filename;
+                } else {
+                    Comp = Comp->newOne(); // static component is used, so create a new one
+                }
+                rot -= Comp->rotated;
+                rot &= 3;
+                while (rot--) Comp->rotate(); // keep last rotation for single component
+                break;
 
-      case Qt::RightButton :  // right mouse button rotates the component
-	if(Comp->Ports.count() == 0)
-	  break;  // do not rotate components without ports
-	Comp->paintScheme(Doc); // erase old component scheme
-	Comp->rotate();
-	Comp->paintScheme(Doc); // paint new component scheme
-	break;
+            case Qt::RightButton :  // right mouse button rotates the component
+                if (Comp->Ports.count() == 0)
+                    break;  // do not rotate components without ports
+                Comp->paintScheme(Doc); // erase old component scheme
+                Doc->viewport()->repaint();
+                Comp->rotate();
+                Comp->paintScheme(Doc); // paint new component scheme
+                break;
 
-      default: ;   // avoids compiler warnings
-    }
+            default:;   // avoids compiler warnings
+        }
 //    qDebug() << "   => selElem = Comp;" << Comp->Name;
-    // comp it getting empty
-    selElem = Comp;
-    return;
+        // comp it getting empty
+        selElem = Comp;
+        return;
 
-  }  // of "if(isComponent)"
-  else if(selElem->Type == isDiagram) {
-    if(Event->button() != Qt::LeftButton) return;
+    }  // of "if(isComponent)"
+    else if (selElem->Type == isDiagram) {
+        if (Event->button() != Qt::LeftButton) return;
 
-    Diagram *Diag = (Diagram*)selElem;
-    QFileInfo Info(Doc->DocName);
-    // dialog is Qt::WDestructiveClose !!!
-    DiagramDialog *dia =
-       new DiagramDialog(Diag, Doc);
-    if(dia->exec() == QDialog::Rejected) {  // don't insert if dialog canceled
-      Doc->viewport()->update();
-      drawn = false;
-      return;
-    }
+        Diagram *Diag = (Diagram *) selElem;
+        QFileInfo Info(Doc->DocName);
+        // dialog is Qt::WDestructiveClose !!!
+        DiagramDialog *dia =
+                new DiagramDialog(Diag, Doc);
+        if (dia->exec() == QDialog::Rejected) {  // don't insert if dialog canceled
+            Doc->viewport()->update();
+            drawn = false;
+            return;
+        }
 
-    Doc->Diagrams->append(Diag);
-    Doc->enlargeView(Diag->cx, Diag->cy-Diag->y2, Diag->cx+Diag->x2, Diag->cy);
-    Doc->setChanged(true, true);   // document has been changed
+        Doc->Diagrams->append(Diag);
+        Doc->enlargeView(Diag->cx, Diag->cy - Diag->y2, Diag->cx + Diag->x2, Diag->cy);
+        Doc->setChanged(true, true);   // document has been changed
 
-    Doc->viewport()->repaint();
-    Diag = Diag->newOne(); // the component is used, so create a new one
-    Diag->paintScheme(Doc);
-    selElem = Diag;
-    return;
-  }  // of "if(isDiagram)"
+        Doc->viewport()->repaint();
+        Diag = Diag->newOne(); // the component is used, so create a new one
+        Diag->paintScheme(Doc);
+        selElem = Diag;
+        return;
+    }  // of "if(isDiagram)"
 
 
   // ***********  it is a painting !!!
@@ -2072,4 +2072,63 @@ void MouseActions::MDoubleClickWire2(Schematic *Doc, QMouseEvent *Event)
   }
 }
 
+void MouseActions::MPressTune(Schematic *Doc, QMouseEvent *Event, float fX, float fY)
+{
+    Q_UNUSED(Event);
+    int No=0;
+    MAx1 = int(fX);
+    MAy1 = int(fY);
+    focusElement = Doc->selectElement(fX, fY, false, &No);
+    isMoveEqual = false;   // moving not neccessarily square
+
+    if(focusElement)
+      // print define value in hex, see element.h
+      qDebug() << "MPressTune: focusElement->Type" <<  QString("0x%1").arg(focusElement->Type, 0, 16);
+    else
+      qDebug() << "MPressTune";
+
+    if(focusElement && App->TuningMode)
+    {
+        Component *pc = nullptr;
+        Property *pp = nullptr;
+        switch(focusElement->Type)
+        {
+        case isComponent: // pick first property if device is clicked (i.e. R,C)
+        case isAnalogComponent:
+            pc = (Component*)focusElement;
+            if(!pc) return;
+            if (pc->Props.isEmpty()) return;
+            pp = pc->Props.at(0);
+            break;
+        case isComponentText:  // property text of component ?
+            focusElement->Type &= (~isComponentText) | isComponent;
+            pc = (Component*)focusElement;
+            pp = 0;
+            if(!pc) return;  // should never happen
+
+            // current property
+            if (No > 0) {
+                No--;// No counts also the on/screen component Name, so subtract 1 to get the actual property number
+                pp = pc->Props.at(No);
+            }
+            if (!pp) return; // should not happen
+            break;
+        default: return;
+        }
+        if (pc == nullptr || pp == nullptr ) return;
+        if (!App->tunerDia->containsProperty(pp) ) {
+            if (checkProperty(pc, pp)) {
+                tunerElement *tune = new tunerElement(App->tunerDia, pc, pp, No);
+                tune->schematicName = Doc->DocName;
+                if (tune != NULL) App->tunerDia->addTunerElement(tune);//Tunable property
+            } else {
+                QMessageBox::warning(nullptr, "Property not correct",
+                                     "You selected a non-tunable property",
+                                     QMessageBox::Ok);
+                return;
+            }
+        }
+    }
+}
+
 // vim:ts=8:sw=2:noet
