@@ -76,6 +76,8 @@ Schematic::Schematic(QucsApp *App_, const QString& Name_)
   UsedX1 = UsedY1 = INT_MAX;
   UsedX2 = UsedY2 = INT_MIN;
 
+  zx1 = zy1 = zx2 = zy2 = dx = dy = 0;
+
   tmpPosX = tmpPosY = -100;
   tmpUsedX1 = tmpUsedY1 = tmpViewX1 = tmpViewY1 = -200;
   tmpUsedX2 = tmpUsedY2 = tmpViewX2 = tmpViewY2 =  200;
@@ -794,6 +796,42 @@ void Schematic::showAll()
   zoom(xScale);
 }
 
+// ------------------------------------------------------
+void Schematic::zoomToSelection() {
+    int x1, x2, y1, y2 = 0;
+    sizeOfSelection(x1, y1, x2, y2);
+    if (x1 == 0 && x2 == 0 && y1 == 0 && y2 == 0) {
+        showAll();
+        return;
+    }
+    //
+    if (zx1 == contentsX() && zx2 == contentsWidth() &&
+        zy1 == contentsY() && zy2 == contentsHeight() &&
+        dx == x2 - x1 &&
+        dy == y2 - y1) {
+        return;
+    }
+
+    dx = x2 - x1;
+    dy = y2 - y1;
+
+    float xScale = float(visibleWidth()) / std::abs(dx + 80);
+    float yScale = float(visibleHeight()) / std::abs(dy + 80);
+    float scale = qMin(xScale, yScale) / Scale;
+    zoom(scale);
+
+    ViewX1 = x1 - 40;
+    ViewY1 = y1 - 40;
+    ViewX2 = x2 + 40;
+    ViewY2 = y2 + 40;
+    zx1 = contentsX();
+    zy1 = contentsY();
+    zx2 = contentsWidth();
+    zy2 = contentsHeight();
+
+    //releaseKeyboard();  // allow keyboard inputs again
+}
+
 // ---------------------------------------------------
 void Schematic::showNoZoom()
 {
@@ -1018,6 +1056,124 @@ void Schematic::sizeOfAll(int& xmin, int& ymin, int& xmax, int& ymax)
   }
 }
 
+void Schematic::sizeOfSelection(int& xmin, int& ymin, int& xmax, int& ymax)
+{
+    xmin=INT_MAX;
+    ymin=INT_MAX;
+    xmax=INT_MIN;
+    ymax=INT_MIN;
+    Component *pc;
+    Diagram *pd;
+    Wire *pw;
+    WireLabel *pl;
+    Painting *pp;
+
+    bool isAnySelected = false;
+
+    if(Components->isEmpty())
+        if(Wires->isEmpty())
+            if(Diagrams->isEmpty())
+                if(Paintings->isEmpty()) {
+                    xmin = xmax = 0;
+                    ymin = ymax = 0;
+                    return;
+                }
+
+
+    float Corr = textCorr();
+    int x1, y1, x2, y2;
+    // find boundings of all components
+    for(pc = Components->first(); pc != 0; pc = Components->next()) {
+        if (!pc->isSelected) {
+            continue;
+        }
+        isAnySelected = true;
+        pc->entireBounds(x1, y1, x2, y2, Corr);
+        if(x1 < xmin) xmin = x1;
+        if(x2 > xmax) xmax = x2;
+        if(y1 < ymin) ymin = y1;
+        if(y2 > ymax) ymax = y2;
+    }
+
+    // find boundings of all wires
+    for(pw = Wires->first(); pw != 0; pw = Wires->next()) {
+        if (!pw->isSelected) {
+            continue;
+        }
+        isAnySelected = true;
+        if(pw->x1 < xmin) xmin = pw->x1;
+        if(pw->x2 > xmax) xmax = pw->x2;
+        if(pw->y1 < ymin) ymin = pw->y1;
+        if(pw->y2 > ymax) ymax = pw->y2;
+
+        pl = pw->Label;
+        if(pl) {     // check position of wire label
+            pl->getLabelBounding(x1,y1,x2,y2);
+            if(x1 < xmin) xmin = x1;
+            if(x2 > xmax) xmax = x2;
+            if(y1 < ymin) ymin = y1;
+            if(y2 > ymax) ymax = y2;
+        }
+    }
+
+    // find boundings of all node labels
+    for(Node *pn = Nodes->first(); pn != 0; pn = Nodes->next()) {
+        if (!pn->isSelected) {
+            continue;
+        }
+        isAnySelected = true;
+        pl = pn->Label;
+        if(pl) {     // check position of node label
+            pl->getLabelBounding(x1,y1,x2,y2);
+            if(x1 < xmin) xmin = x1;
+            if(x2 > xmax) xmax = x2;
+            if(y1 < ymin) ymin = y1;
+            if(y2 > ymax) ymax = y2;
+        }
+    }
+
+    // find boundings of all diagrams
+    for(pd = Diagrams->first(); pd != 0; pd = Diagrams->next()) {
+        if (!pd->isSelected) {
+            continue;
+        }
+        isAnySelected = true;
+        pd->Bounding(x1, y1, x2, y2);
+        if(x1 < xmin) xmin = x1;
+        if(x2 > xmax) xmax = x2;
+        if(y1 < ymin) ymin = y1;
+        if(y2 > ymax) ymax = y2;
+
+        for (Graph *pg : pd->Graphs)
+            // test all markers of diagram
+            for (Marker *pm : pg->Markers) {
+                pm->Bounding(x1, y1, x2, y2);
+                if(x1 < xmin) xmin = x1;
+                if(x2 > xmax) xmax = x2;
+                if(y1 < ymin) ymin = y1;
+                if(y2 > ymax) ymax = y2;
+            }
+    }
+
+    // find boundings of all Paintings
+    for(pp = Paintings->first(); pp != nullptr; pp = Paintings->next()) {
+        if (!pp->isSelected) {
+            continue;
+        }
+        isAnySelected = true;
+        pp->Bounding(x1, y1, x2, y2);
+        if(x1 < xmin) xmin = x1;
+        if(x2 > xmax) xmax = x2;
+        if(y1 < ymin) ymin = y1;
+        if(y2 > ymax) ymax = y2;
+    }
+
+    if (!isAnySelected) {
+        xmin = xmax = 0;
+        ymin = ymax = 0;
+    }
+}
+
 // ---------------------------------------------------
 // Rotates all selected components around their midpoint.
 bool Schematic::rotateElements()
@@ -1911,7 +2067,6 @@ void Schematic::contentsWheelEvent(QWheelEvent *Event)
       viewport()->update(); // because QScrollView thinks nothing has changed
       App->view->drawn = false;
   }
-
   Event->accept();   // QScrollView must not handle this event
 }
 
@@ -2206,7 +2361,7 @@ bool Schematic::checkDplAndDatNames()
     if(!DocName.isEmpty() &&
         DataSet.size()>4 &&
         DataDisplay.size()>4) {
-      QString base = Info.baseName();
+      QString base = Info.completeBaseName();
       QString base_dat = DataSet;
       base_dat.chop(4);
       QString base_dpl = DataDisplay;
@@ -2217,8 +2372,8 @@ bool Schematic::checkDplAndDatNames()
                                     "instead of using File->SaveAs. Correct dataset and display names "
                                     "automatically?\n\n");
           msg += QString(QObject::tr("Schematic file: ")) + base + ".sch\n";
-          msg += QString(QObject::tr("Dataset file: ")) + base_dat + ".sch \n";
-          msg += QString(QObject::tr("Display file: ")) + base_dpl + ".sch\n";
+          msg += QString(QObject::tr("Dataset file: ")) + DataSet + "\n";
+          msg += QString(QObject::tr("Display file: ")) + DataDisplay + "\n";
           auto r = QMessageBox::information(this,
                                            QObject::tr("Open document"),
                                            msg, QMessageBox::Yes, QMessageBox::No);
